@@ -1,9 +1,9 @@
 package Test::Smoke::Mailer;
 use strict;
 
-# $Id: Mailer.pm 691 2004-04-30 16:24:02Z abeltje $
+# $Id: Mailer.pm 1044 2007-04-06 22:01:03Z abeltje $
 use vars qw( $VERSION $P5P $NOCC_RE);
-$VERSION = '0.009';
+$VERSION = '0.014';
 
 use Test::Smoke::Util qw( parse_report_Config );
 
@@ -13,9 +13,12 @@ my %CONFIG = (
     df_mailer        => 'Mail::Sendmail',
     df_ddir          => undef,
     df_v             => 0,
+    df_rptfile       => 'mktest.rpt',
     df_to            => 'daily-build-reports@perl.org',
     df_from          => '',
     df_cc            => '',
+    df_swcc          => '-c',
+    df_swbcc         => '-b',
     df_bcc           => '',
     df_ccp5p_onfail  => 0,
     df_mserver       => 'localhost',
@@ -23,7 +26,7 @@ my %CONFIG = (
     df_mailbin       => 'mail',
     mail             => [qw( bcc cc mailbin )],
     df_mailxbin      => 'mailx',
-    mailx            => [qw( bcc cc mailxbin )],
+    mailx            => [qw( bcc cc mailxbin swcc swbcc )],
     df_sendmailbin   => 'sendmail',
     sendmail         => [qw( from bcc cc sendmailbin )],
     'Mail::Sendmail' => [qw( from bcc cc mserver )],
@@ -90,7 +93,7 @@ sub  new {
     my %fields = map {
         my $value = exists $args{$_} ? $args{ $_ } : $CONFIG{ "df_$_" };
         ( $_ => $value )
-    } ( v => ddir => to => ccp5p_onfail => @{ $CONFIG{ $mailer } } );
+    } ( rptfile => v => ddir => to => ccp5p_onfail => @{ $CONFIG{ $mailer } } );
     $fields{ddir} = File::Spec->rel2abs( $fields{ddir} );
 
     DO_NEW: {
@@ -116,7 +119,7 @@ subject line for the mail-message.
 sub fetch_report {
     my $self = shift;
 
-    my $report_file = File::Spec->catfile( $self->{ddir}, 'mktest.rpt' );
+    my $report_file = File::Spec->catfile( $self->{ddir}, $self->{rptfile} );
 
     local *REPORT;
     if ( open REPORT, "< $report_file" ) {
@@ -124,7 +127,7 @@ sub fetch_report {
         close REPORT;
     } else {
         require Carp;
-        Carp::croak "Cannot read '$report_file': $!";
+        Carp::croak( "Cannot read '$report_file': $!" );
     }
 
     my @config = parse_report_Config( $self->{body} );
@@ -319,8 +322,9 @@ sub mail {
     my $cc = $self->_get_cc( $subject );
 
     my $cmdline = qq|$mailer -s '$subject'|;
-    $cmdline   .= qq| -c '$cc'| if $cc;
-    $cmdline   .= qq| -b '$self->{bcc}'| if $self->{bcc};
+    $self->{swcc}  ||= '-c', $cmdline   .= qq| $self->{swcc} '$cc'| if $cc;
+    $self->{swbcc} ||= '-b', $cmdline   .= qq| $self->{swbcc} '$self->{bcc}'|
+        if $self->{bcc};
     $cmdline   .= qq| $self->{to}|;
 
     $self->{v} > 1 and print "[$cmdline]\n";
@@ -398,6 +402,9 @@ sub mail {
     $message{from} = $self->{from} if $self->{from};
     $message{smtp} = $self->{mserver} if $self->{mserver};
 
+    $message{ 'Content-type' } = qq!text/plain; charset="UTF8"!
+        if exists $ENV{LANG} && $ENV{LANG} =~ /utf-?8$/i;
+
     $self->{v} > 1 and print "[Mail::Sendmail]\n";
     $self->{v} and print "Sending report to $self->{to} ";
 
@@ -468,9 +475,13 @@ sub mail {
     $message{Cc}   = $cc  if $cc;
     $message{Bcc}   = $self->{bcc} if $self->{bcc};
     $message{From} = $self->{from} if $self->{from};
-    MIME::Lite->send( smtp => $self->{mserver} ) if $self->{mserver};
+
+    MIME::Lite->send( smtp => $self->{mserver}, Debug => ( $self->{v} > 1 ) )
+        if $self->{mserver};
 
     my $ml_msg = MIME::Lite->new( %message );
+    $ml_msg->attr( 'content-type.charset' => 'UTF8' )
+        if exists $ENV{LANG} && $ENV{LANG} =~ /utf-?8$/i;
 
     $self->{v} > 1 and print "[MIME::Lite]\n";
     $self->{v} and print "Sending report to $self->{to} ";
